summaryrefslogtreecommitdiffstats
path: root/kmail/objecttreeparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/objecttreeparser.h')
-rw-r--r--kmail/objecttreeparser.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/objecttreeparser.h b/kmail/objecttreeparser.h
index f9e71427..b864ea61 100644
--- a/kmail/objecttreeparser.h
+++ b/kmail/objecttreeparser.h
@@ -169,13 +169,13 @@ namespace KMail {
KMail::CSSHelper * cssHelper() const { return mCSSHelper; }
/** Parse beginning at a given node and recursively parsing
- the children of that node and it's next sibling. */
+ the tqchildren of that node and it's next sibling. */
// Function is called internally by "parseMsg(KMMessage* msg)"
// and it will be replaced once KMime is alive.
void parseObjectTree( partNode * node );
private:
/** Standard children handling a.k.a. multipart/mixed (w/o
kroupware hacks) */
void stdChildHandling( partNode * child );
@@ -169,13 +169,13 @@ namespace KMail {
void parseObjectTree( partNode * node );
private:
- /** Standard children handling a.k.a. multipart/mixed (w/o
+ /** Standard tqchildren handling a.k.a. multipart/mixed (w/o
kroupware hacks) */
void stdChildHandling( partNode * child );